@@ -189,13 +189,6 @@ recode <- function(dat,xm) {
 fblo<-function(x,i,bigB) {
 	if(x > 1)  return(rep(0,x))				# multinomial
 	if(x== 1)  return(c(-bigB,-bigB))		# normal (mu - mean, sigma - stddev)
-	if(x== 0)  return(c(-bigB,+bigB))		# uniform (a - lower, b - upper)
-	if(x==-21) return(c(-bigB,0)) 			# lognormal (a - meanlog, b - sdlog)
-	if(x==-22) return(c(0,0)) 				# weibull (a -shape , g - scale)
-	if(x==-23) return(c(0,0)) 				# gamma   (a - shape, b scale)
-	if(x==-31) return(c(-bigB,0,-bigB)) 	# 3lognormal (a - meanlog, b - sdlog, c - shift)
-	if(x==-32) return(c(0,0,-bigB)) 		# 3 weibull (a -shape , g - scale, shift)
-	if(x==-33) return(c(0,0,-bigB)) 		# 3 gamma   (a - shape, b scale, shift)
 }
 
 # function fbuo gives upper bounds of parameters for each density
@@ -203,39 +196,18 @@ fbuo<-function(x,i,bigB) {
 	ubshift=+bigB	
 	if(x > 1)  return(rep(1,x)) 				# multinomial
 	if(x==1)   return(c(+bigB,+bigB)) 			# normal (mu - mean, sigma - stddev)
-	if(x==0)   return(c(-bigB,+bigB))			# uniform (a - lower,b - upper)
-	if(x==-21) return(c(+bigB,+bigB))			# lognormal (a - meanlog, b - sdlog)
-	if(x==-22) return(c(+bigB,+bigB)) 			# weibull (a - shape, g - scale)
-	if(x==-23) return(c(+bigB,+bigB))			# gamma   (a - shape, b scale)
-	if(x==-31) return(c(+bigB,+bigB,ubshift))	# 3lognormal (a - meanlog, b - sdlog, c - shift)
-	if(x==-32) return(c(+bigB,+bigB,ubshift)) 	# 3weibull (a - shape, g - scale)
-	if(x==-33) return(c(+bigB,+bigB,ubshift))	# 3gamma   (a - shape, b scale)
 }
 
 # function ppar generates random start values of parameters for each density and pastes stvals together
 ppar<-function(x,z) {
 	if(x > 1)  {y<-runif(x);y<-y/sum(y)} 							# multinomial
-	if(x==1)    y<-c(rnorm(1,10,1), runif(1,1,2)) 					# normal (mu - mean, sigma - stddev)
-	if(x== 0)   y<-c(runif(1,-10,1),runif(1,3,10))					# uniform (a - lower, b - upper)
-	if(x== -21) y<-c(rnorm(1,0,3),  runif(1,.5,3)) 					# lognormal (a - meanlog, b - sdlog)
-	if(x== -22) y<-c(runif(1,.5,3), runif(1,.5,3)) 					# weibull (a - shape, g - scale)
-	if(x== -23) y<-c(runif(1,.5,11),runif(1,.001,1)) 				# gamma   (a - shape, b scale)
-	if(x== -31) y<-c(rnorm(1,0,3),  runif(1,.5,3),runif(1,-2,0)) 	# 3lognormal (a - meanlog, b - sdlog, c - shift)
-	if(x== -32) y<-c(runif(1,.5,3), runif(1,.5,3), runif(1,-2,0)) 	# 3weibull (a - shape, g - scale)
-	if(x== -33) y<-c(runif(1,.5,11),runif(1,.001,1), runif(1,-2,0))	# 3gamma   (a - shape, b scale)
+	if(x==1)    y<-c(rnorm(1), rnorm(1,1,0.1)) 						# normal (mu - mean, sigma - stddev)
 	return(c(z,y)) 
 }
 
 #recode itemtypes from characters to magic numbers
 recitt <- function(itemtypes) {
 	itemtypes[itemtypes=="gaussian"|itemtypes=="normal"|itemtypes=="norm"]=1
-	itemtypes[itemtypes=="uniform"|itemtypes=="unif"]=0
-	itemtypes[itemtypes=="lognormal"|itemtypes=="lnorm"]=-21
-	itemtypes[itemtypes=="weibull"]=-22
-	itemtypes[itemtypes=="gamma"]=-23
-	itemtypes[itemtypes=="3lognormal"|itemtypes=="3lnorm"]=-31
-	itemtypes[itemtypes=="3weibull"]=-32
-	itemtypes[itemtypes=="3gamma"]=-33
 	itemtypes=as.numeric(itemtypes)
 	itemtypes
 }
@@ -244,13 +216,6 @@ recitt <- function(itemtypes) {
 pp<-function(x){
 	if(x > 1)  return(paste("p",1:x)) # multinomial
 	if(x== 1)  return(c("mean", "stddev"))  # normal
-	if(x== 0)  return(c("lower","upper")) # uniform
-	if(x==-21) return(c("meanlog", "sdlog")) # lognormal
-	if(x==-22) return(c("shape","scale")) # weibull
-	if(x==-23) return(c("shape","scale")) # gamma
-	if(x==-31) return(c("meanlog", "sdlog","shift")) # 3lognormal
-	if(x==-32) return(c("shape","scale","shift")) # 3weibull
-	if(x==-33) return(c("shape","scale","shift")) # 3gamma
 }
 
 # returns the number of parameters for each density
@@ -258,15 +223,11 @@ np <- function(x) {
 	if(x > 1)  {
 		return(x) 
 	} else {
-		if(x < -30)  {
-			return(3) 
+		if(x==1) {
+			return(2)
 		} else {
-			if (x< -20|x==1|x==0) {
-				return(2)
-			} else {
-				stop("Unknown itemtype code in function np.")
-			}
-		}	
+			stop("Unknown itemtype code in function np.")
+		}
 	}
 }
 
@@ -365,13 +326,6 @@ paridx <- function(nstates,itemtypes,mat,idx1=0,idx2=0,it=0,comp=1,group=1) {
 fresp <- function(x,pars) {
 	if(x > 1)  resp = which(rmultinom(1,size=1,prob=pars)==1)	# multinomial
 	if(x==1)   resp = rnorm(1,pars[1],pars[2]) 					# normal (mu - mean, sigma - stddev)
-	if(x==0)   resp = runif(1,pars[1],pars[2])					# uniform 
-	if(x==-21) resp = rlnorm(1,pars[1],pars[2])  				# lognormal (a - meanlog, b - sdlog)
-	if(x==-22) resp = rweibull(1,pars[1],pars[2])  				# weibull (a - shape, g - scale)
-	if(x==-23) resp = rgamma(1,pars[1],scale=pars[2])  			# gamma   (a - shape, b scale)
-	if(x==-31) resp = pars[3]+ rlnorm(1,pars[1],pars[2])  		# 3lognormal (a - meanlog, b - sdlog, c shift)
-	if(x==-32) resp = pars[3]+ rweibull(1,pars[1],pars[2])  	# 3weibull (a - shape, g - scale, c shift)
-	if(x==-33) resp = pars[3]+ rgamma(1,pars[1],scale=pars[2])	# 3gamma   (a - shape, b scale, c shift)
 	return(resp) 
 }
 
